diff src/gtkimhtml.h @ 9037:960bb3bd9ba6

[gaim-migrate @ 9813] simguy broke gaim in more ways than one. but he was around to fix it. committer: Tailor Script <tailor@pidgin.im>
author Luke Schierer <lschiere@pidgin.im>
date Sun, 23 May 2004 19:39:38 +0000
parents bbb8733c7818
children 812e7aa7eafa
line wrap: on
line diff
--- a/src/gtkimhtml.h	Sun May 23 19:03:49 2004 +0000
+++ b/src/gtkimhtml.h	Sun May 23 19:39:38 2004 +0000
@@ -212,11 +212,11 @@
 /*@{*/
 
 /**
  * Returns the GtkType object for an IM/HTML widget.
  *
- * @return The GtkType for an IM/HTML widget.
+ * @return The GType for an IM/HTML widget.
  */
-GtkType gtk_imhtml_get_type(void);
+GType gtk_imhtml_get_type(void);
 
 /**
  * Creates and returns a new GTK IM/HTML widget.
@@ -212,11 +212,11 @@
 
 /**
- * Returns the GtkType object for an IM/HTML widget.
+ * Returns the GType object for an IM/HTML widget.
  *